Save all plots in a list at once to a given directory.

batch_save(
  data,
  plot_list = plots,
  file_name_list = file_names,
  path,
  width = NA,
  height = NA
)

Arguments

data

A dataframe containing a list column of plots

plot_list

A string indicating the plot column

file_name_list

A string indicating the file name column

path

A string to a directory where plots should be saved

width

Numeric, plot width

height

Numeric, plot height