Baujat plots to identify potential study outliers.

baujat_plot(
  x,
  xlim,
  ylim,
  xlab,
  ylab,
  cex,
  symbol,
  grid = TRUE,
  progbar = FALSE,
  plot_title,
  ...
)

Arguments

x

an object of class "rma".

xlim

x-axis limits. If unspecified, the function tries to set the x-axis limits to some sensible values.

ylim

y-axis limits. If unspecified, the function tries to set the y-axis limits to some sensible values.

xlab

title for the x-axis. If unspecified, the function tries to set an appropriate axis title.

ylab

title for the y-axis. If unspecified, the function tries to set an appropriate axis title.

cex

optional character expansion factor. If unspecified, the function tries to set this to a sensible value.

symbol

either an integer to specify the pch value (i.e., plotting symbol), or "slab" to plot the study labels, or "ids" (the default) to plot the study id numbers.

grid

logical to specify whether a grid should be added to the plot (can also be a color name).

progbar

logical to specify whether a progress bar should be shown (the default is FALSE).

plot_title

A string, the plot title

...

other arguments.

https://github.com/cran/metafor/blob/master/R/baujat.rma.r