Calculate the three-level meta-analysis with restricted maximum-likelihood and Knapp-Hartung adjustement for confidence intervals. In some cases, there is only one study_id or intervention_id. In this case, the function would throw a message, which is suppressed as we know what is happening there.

calc_meta_analysis(data, ...)

Arguments

data

A data frame containing data for a meta-analysis

...

Additional options passed to metafor::rma.mv()

Value

An object of class rma.mv