Calculate a three-level meta-analysis for a given comparison without a particular study.

meta_analysis_without(data, analysis_number, comparison, without, ...)

Arguments

data

A dataframe containing the effect sizes, CI and analysis numbers

analysis_number

Numeric, the analysis number

comparison

A string, the measurement against "pre" should be compared

without

A string, the study's first author of who the study should be omitted

...

Additional options